@@ -1,10 +1,11 @@
 """FastAPI framework, high performance, easy to learn, fast to code, ready for production"""
 
-__version__ = "0.49.2"
+__version__ = "0.51.0"
 
-from starlette.background import BackgroundTasks
+from starlette import status
 
 from .applications import FastAPI
+from .background import BackgroundTasks
 from .datastructures import UploadFile
 from .exceptions import HTTPException
 from .param_functions import (
@@ -18,4 +19,7 @@ from .param_functions import (
     Query,
     Security,
 )
+from .requests import Request
+from .responses import Response
 from .routing import APIRouter
+from .websockets import WebSocket
