@@ -1,6 +1,6 @@
 import pytest
 from fastapi import APIRouter, FastAPI
-from starlette.testclient import TestClient
+from fastapi.testclient import TestClient
 
 app = FastAPI()
 
@@ -21,10 +21,12 @@ client = TestClient(app)
 def test_use_empty():
     with client:
         response = client.get("/prefix")
+        assert response.status_code == 200
         assert response.json() == ["OK"]
 
         response = client.get("/prefix/")
-        assert response.status_code == 404
+        assert response.status_code == 200
+        assert response.json() == ["OK"]
 
 
 def test_include_empty():
