@@ -2,8 +2,8 @@ from typing import Optional
 
 from fastapi import Depends, FastAPI, Security
 from fastapi.security import APIKeyQuery
+from fastapi.testclient import TestClient
 from pydantic import BaseModel
-from starlette.testclient import TestClient
 
 app = FastAPI()
 
